@@ -70,7 +70,6 @@ Handler::Handler(QObject *parent)
     }
 
     m_hotspotSupported = checkHotspotSupported();
-    m_runningLiveImage = checkRunningLiveImage();
 
     if (NetworkManager::checkVersion(1, 16, 0)) {
         connect(NetworkManager::notifier(), &NetworkManager::Notifier::primaryConnectionTypeChanged, this, &Handler::primaryConnectionTypeChanged);
@@ -242,7 +241,8 @@ void Handler::addAndActivateConnection(const QString &device, const QString &spe
     settings->setId(ap->ssid());
     settings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
     settings->setAutoconnect(true);
-    settings->addToPermissions(KUser().loginName(), QString());
+
+    UiUtils::setConnectionDefaultPermissions(settings);
 
     NetworkManager::WirelessSetting::Ptr wifiSetting = settings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
     wifiSetting->setInitialized(true);
@@ -283,16 +283,12 @@ void Handler::addAndActivateConnection(const QString &device, const QString &spe
         m_tmpSpecificPath = specificObject;
 
         QPointer<ConnectionEditorDialog> editor = new ConnectionEditorDialog(settings);
+        editor->setAttribute(Qt::WA_DeleteOnClose);
         editor->show();
         KWindowSystem::setState(editor->winId(), NET::KeepAbove);
         KWindowSystem::forceActiveWindow(editor->winId());
-        connect(editor.data(), &ConnectionEditorDialog::accepted, [editor, this]() {
-            addConnection(editor->setting());
-        });
-        connect(editor.data(), &ConnectionEditorDialog::finished, [editor]() {
-            if (editor) {
-                editor->deleteLater();
-            }
+        connect(editor.data(), &ConnectionEditorDialog::accepted, [editor, device, specificObject, this]() { //
+            addAndActivateConnectionDBus(editor->setting(), device, specificObject);
         });
         editor->setModal(true);
         editor->show();
@@ -300,9 +296,6 @@ void Handler::addAndActivateConnection(const QString &device, const QString &spe
         if (securityType == NetworkManager::StaticWep) {
             wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::Wep);
             wifiSecurity->setWepKey0(password);
-            if (KWallet::Wallet::isEnabled() && !m_runningLiveImage) {
-                wifiSecurity->setWepKeyFlags(NetworkManager::Setting::AgentOwned);
-            }
         } else {
             if (ap->mode() == NetworkManager::AccessPoint::Adhoc) {
                 wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::WpaNone);
@@ -310,15 +303,8 @@ void Handler::addAndActivateConnection(const QString &device, const QString &spe
                 wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::WpaPsk);
             }
             wifiSecurity->setPsk(password);
-            if (KWallet::Wallet::isEnabled() && !m_runningLiveImage) {
-                wifiSecurity->setPskFlags(NetworkManager::Setting::AgentOwned);
-            }
         }
-        QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addAndActivateConnection(settings->toMap(), device, specificObject);
-        auto watcher = new QDBusPendingCallWatcher(reply, this);
-        watcher->setProperty("action", Handler::AddAndActivateConnection);
-        watcher->setProperty("connection", settings->name());
-        connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
+        addAndActivateConnectionDBus(settings->toMap(), device, specificObject);
     }
 
     settings.clear();
@@ -333,6 +319,15 @@ void Handler::addConnection(const NMVariantMapMap &map)
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
+void Handler::addAndActivateConnectionDBus(const NMVariantMapMap &map, const QString &device, const QString &specificObject)
+{
+    QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addAndActivateConnection(map, device, specificObject);
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
+    watcher->setProperty("action", AddAndActivateConnection);
+    watcher->setProperty("connection", map.value(QStringLiteral("connection")).value(QStringLiteral("id")));
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
+}
+
 void Handler::deactivateConnection(const QString &connection, const QString &device)
 {
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
@@ -703,25 +698,6 @@ bool Handler::checkHotspotSupported()
     return false;
 }
 
-bool Handler::checkRunningLiveImage()
-{
-    QFile cmdFile(QStringLiteral("/proc/cmdline"));
-    cmdFile.open(QIODevice::ReadOnly);
-
-    if (!cmdFile.isOpen()) {
-        return false;
-    }
-
-    const QString cmdFileOutput = cmdFile.readAll();
-    cmdFile.close();
-
-    if (cmdFileOutput.contains(QStringLiteral("rd.live.image"))) {
-        return true;
-    }
-
-    return false;
-}
-
 void Handler::scheduleRequestScan(const QString &interface, int timeout)
 {
     QTimer *timer;
